# HelperRoutines.jl

# PRIVATE FUNCTION
#
# The purpose of this function is to extract optional arguments and set 
# default values for non-supplied arguments.
function extract_options(args)
    o = Dict{Symbol, Any}(args)

    if haskey(o, :alg_hints)
        hints = o[:reltol]
    else
        hints = [:stiff]
    end

    if haskey(o, :reltol)
        reltol = o[:reltol]
    else
        reltol = 1e-8
    end

    if haskey(o, :abstol)
        abstol = o[:abstol]
    else
        abstol = 1e-6
    end

    if haskey(o, :dtmax)
        dtmax = o[:dtmax]
    else
        dtmax = 1e-3
    end

    if haskey(o, :maxiters)
        mi = o[:maxiters]
    else
        mi = 1000000
    end

    if haskey(o, :pointspercycle)
        ppc = o[:pointspercycle]
    else
        ppc = 1024
    end

    if haskey(o, :cyclecount)
        cc = o[:cyclecount]
    else
        cc = 4
    end

    if haskey(o, :transientcount)
        tc = o[:transientcount]
    else
        tc = 20
    end

    if haskey(o, :windowsize)
        ws = o[:windowsize]
    else
        ws = 2048
    end

    if haskey(o, :windowfunction)
        wf = o[:windowfunction]
    else
        wf = DSP.Windows.hanning
    end

    if haskey(o, :modelparams)
        mp = o[:modelparams]
    else
        mp = empty
    end

    # Output
    return (
        alg_hints = hints,
        reltol = reltol,
        abstol = abstol,
        dtmax = dtmax,
        maxiters = mi,
        pointspercycle = ppc,
        cyclecount = cc,
        transientcount = tc,
        windowsize = ws,
        windowfunction = wf,
        modelparams = mp
    )
end